@@ -223,6 +223,7 @@ psutil_proc_oneshot_info(PyObject *self, PyObject *args) {
         PyErr_Clear();
         py_name = Py_None;
     }
+    // Py_INCREF(py_name);
 
     // Calculate memory.
 #ifdef PSUTIL_FREEBSD
@@ -343,10 +344,7 @@ psutil_proc_oneshot_info(PyObject *self, PyObject *args) {
         py_name                           // (pystr) name
     );
 
-    if (py_retlist != NULL) {
-        // XXX shall we decref() also in case of Py_BuildValue() error?
-        Py_DECREF(py_name);
-    }
+    Py_DECREF(py_name);
     return py_retlist;
 }
 
@@ -804,7 +802,7 @@ psutil_users(PyObject *self, PyObject *args) {
 
     fp = fopen(_PATH_UTMP, "r");
     if (fp == NULL) {
-        PyErr_SetFromErrno(PyExc_OSError);
+        PyErr_SetFromErrnoWithFilename(PyExc_OSError, _PATH_UTMP);
         goto error;
     }
 
